ToggleLensType class final
An implementation of SwitchCameraOption that cycles through available lens types on the current camera facing direction.
This option cycles through the available lens types in order: normal -> wide -> zoom -> normal (wrapping around).
If a lens type is not available on the device, it will be skipped.
- Inheritance
-
- Object
- SwitchCameraOption
- ToggleLensType
Constructors
- ToggleLensType()
-
Creates a toggle lens type request.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited